@@ -4,5 +4,5 @@
 from .api import *
 
 # Consumer key / secret of the "TweetPony" application. Can be used for example purposes.
-CONSUMER_KEY = "acZe1khMjIvsg1g8izdag"
-CONSUMER_SECRET = "B9E3gmuQSZPaEhwGEBD7879oNHydbdWnjRKyB7b1ag"
\ No newline at end of file
+CONSUMER_KEY = "FawBJCoKmeSceTXuphnw"
+CONSUMER_SECRET = "vG20yKxANrI5yaMdiMiokWDTgWSIUwD422fUfzGsDc"
\ No newline at end of file
